@@ -81,10 +81,16 @@ class InterpND(object):
     extrapolate : bool
         If False, when interpolated values are requested outside of the domain of the input
         data, a ValueError is raised. If True, then the methods are allowed to extrapolate.
-        Default is True (raise an exception).
+        Default is False (raise an exception).
     num_cp : None or int
         Optional. When specified, use a linear distribution of num_cp control points. If you
         are using 'bsplines' as the method, then num_cp must be set instead of points.
+    x_cp_start : None or float
+        Optional, for bsplines only. Location of first control point if not on the first
+        interpolation point.
+    x_cp_end : None or float
+        Optional, for bsplines only. Location of last control point if not on the last
+        interpolation point.
     **kwargs : dict
         Interpolator-specific options to pass onward.
 
@@ -93,7 +99,6 @@ class InterpND(object):
     extrapolate : bool
         If False, when interpolated values are requested outside of the domain of the input data,
         a ValueError is raised. If True, then the methods are allowed to extrapolate.
-        Default is True.
     grid : tuple
         Collection of points that determine the regular grid.
     table : <InterpTable>
@@ -120,7 +125,7 @@ class InterpND(object):
     """
 
     def __init__(self, method="slinear", points=None, values=None, x_interp=None, extrapolate=False,
-                 num_cp=None, **kwargs):
+                 num_cp=None, x_cp_start=None, x_cp_end=None, **kwargs):
         """
         Initialize an InterpND object.
 
@@ -198,6 +203,13 @@ class InterpND(object):
                     raise ValueError("There are %d points and %d values in "
                                      "dimension %d" % (len(p), values.shape[i], i))
 
+        else:
+            # interpolating spline
+
+            if method == 'bsplines':
+                kwargs['x_cp_start'] = x_cp_start
+                kwargs['x_cp_end'] = x_cp_end
+
         self.grid = tuple([np.asarray(p) for p in points])
         self.values = values
         self.x_interp = x_interp
