@@ -1,5 +1,4 @@
 import os
-import pathlib
 import unittest
 
 import numpy as np
@@ -12,10 +11,8 @@ from openmdao.test_suite.components.expl_comp_array import TestExplCompArrayDens
 from openmdao.test_suite.components.simple_comps import DoubleArrayComp
 from openmdao.test_suite.components.paraboloid import Paraboloid
 from openmdao.test_suite.components.sellar import SellarDerivativesGrouped
-from openmdao.utils.assert_utils import assert_warning
 
 from openmdao.utils.mpi import MPI
-from openmdao.utils.om_warnings import DriverWarning
 from openmdao.utils.testing_utils import use_tempdirs, require_pyoptsparse
 from openmdao.utils.tests.test_hooks import hooks_active
 
@@ -113,7 +110,7 @@ class TestOptimizationReport(unittest.TestCase):
         """
         if prob is None:
             prob = self.prob
-        report_file_path = str(pathlib.Path(prob.get_reports_dir()).joinpath(_default_optimizer_report_filename))
+        report_file_path = prob.get_reports_dir() / _default_optimizer_report_filename
 
         check_rows = {
             # 'runtime': 'Wall clock run time:',
@@ -134,7 +131,7 @@ class TestOptimizationReport(unittest.TestCase):
             else:
                 try:
                     value = int(value)
-                except ValueError as err:
+                except ValueError:
                     pass
             return value
 
@@ -165,12 +162,9 @@ class TestOptimizationReport(unittest.TestCase):
 
         self.check_opt_result(expected=expect)
 
-        expected_warning_msg = "The optimizer report is not applicable for Driver type 'Driver', " \
-                               "which does not support optimization"
-        with assert_warning(DriverWarning, expected_warning_msg):
-            opt_report(self.prob)
+        opt_report(self.prob)
 
-        outfilepath = str(pathlib.Path(self.prob.get_reports_dir()).joinpath(_default_optimizer_report_filename))
+        outfilepath = self.prob.get_reports_dir() / _default_optimizer_report_filename
         self.assertFalse(os.path.exists(outfilepath))
 
     def test_opt_report_scipyopt_SLSQP(self):
@@ -252,11 +246,8 @@ class TestOptimizationReport(unittest.TestCase):
 
         self.check_opt_result(prob.driver.result, expected={'model_evals': 5, 'deriv_evals': 0})
 
-        expected_warning_msg = "The optimizer report is not applicable for Driver type 'DOEDriver', " \
-                               "which does not support optimization"
-        with assert_warning(DriverWarning, expected_warning_msg):
-            opt_report(prob)
-        outfilepath = str(pathlib.Path(prob.get_reports_dir()).joinpath(_default_optimizer_report_filename))
+        opt_report(prob)
+        outfilepath = prob.get_reports_dir() / _default_optimizer_report_filename
         self.assertFalse(os.path.exists(outfilepath))
 
     @unittest.skipUnless(pyDOE3, "requires 'pyDOE3', install openmdao[doe]")
@@ -555,7 +546,7 @@ class TestOptimizationReport(unittest.TestCase):
         prob.run_driver()
 
         opt_report(self.prob)
-        report_file_path = str(pathlib.Path(prob.get_reports_dir()).joinpath(_default_optimizer_report_filename))
+        report_file_path = prob.get_reports_dir() / _default_optimizer_report_filename
 
         with open(report_file_path, 'r') as f:
             for line in f.readlines():
